Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/js
diff options
context:
space:
mode:
authormattab <matthieu.aubry@gmail.com>2013-02-26 11:57:20 +0400
committermattab <matthieu.aubry@gmail.com>2013-02-26 11:57:20 +0400
commitc405a15af93d981bee32d26a8f38ee1371d9be78 (patch)
treeaa9862b52334866766e68ed457b985fd804d43d1 /js
parentb562ded89964307f83379c8b4e6b2366b77208b9 (diff)
Refs #1845
* the tests/js is now passing following Benaka's commit, sweeet * Adding setsiteId to the "special case" so that setSiteId can be called after trackpageView and it still works * Adding pathname in the generated JS * HTML entity the & in the IMG src
Diffstat (limited to 'js')
-rw-r--r--js/piwik.js10
1 files changed, 6 insertions, 4 deletions
diff --git a/js/piwik.js b/js/piwik.js
index e1fe744a57..4c2dbe23b3 100644
--- a/js/piwik.js
+++ b/js/piwik.js
@@ -2523,8 +2523,9 @@ var
/**
* Strip hash tag (or anchor) from URL
- * TODO: Remove as it is now part of core #3232
+ * Note: this can be done in the Piwik>Settings>Websites on a per-website basis
*
+ * @deprecated
* @param bool enableFilter
*/
discardHashTag: function (enableFilter) {
@@ -2882,10 +2883,11 @@ var
Date.prototype.getTimeAlias = Date.prototype.getTime;
asyncTracker = new Tracker();
-
- // find the call to setTrackerUrl (if any) and call it first
+
+ // find the call to setTrackerUrl or setSiteid (if any) and call them first
for (i = 0; i < _paq.length; i++) {
- if (_paq[i][0] == 'setTrackerUrl') {
+ if (_paq[i][0] === 'setTrackerUrl'
+ || _paq[i][0] === 'setSiteId') {
apply(_paq[i]);
delete _paq[i];
}